@@ -35,8 +35,6 @@
 #include "eog-application-internal.h"
 #include "eog-util.h"
 
-#include "totem-scrsaver.h"
-
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -227,15 +225,9 @@ eog_application_init_app_menu (EogApplication *application)
 static void
 eog_application_startup (GApplication *application)
 {
-	EogApplication *app = EOG_APPLICATION (application);
-
 	G_APPLICATION_CLASS (eog_application_parent_class)->startup (application);
 
-	eog_application_init_app_menu (app);
-	app->priv->scr_saver = totem_scrsaver_new();
-	g_object_set (app->priv->scr_saver,
-	              "reason", "Running in fullscren mode",
-	              NULL);
+	eog_application_init_app_menu (EOG_APPLICATION (application));
 }
 
 static void
@@ -284,8 +276,6 @@ eog_application_finalize (GObject *object)
 		priv->plugin_engine = NULL;
 	}
 
-	g_clear_object (&priv->scr_saver);
-
 	g_clear_object (&priv->ui_settings);
 
 	eog_application_save_accelerators ();
@@ -740,34 +730,6 @@ eog_application_reset_toolbars_model (EogApplication *app)
 				      EGG_TB_MODEL_NOT_REMOVABLE);
 }
 
-/**
- * eog_application_screensaver_enable:
- * @application: an #EogApplication.
- *
- * Enables the screensaver. Usually necessary after a call to
- * eog_application_screensaver_disable().
- **/
-void
-eog_application_screensaver_enable (EogApplication *application)
-{
-	if (application->priv->scr_saver)
-		totem_scrsaver_enable (application->priv->scr_saver);
-}
-
-/**
- * eog_application_screensaver_disable:
- * @application: an #EogApplication.
- *
- * Disables the screensaver. Useful when the application is in fullscreen or
- * similar mode.
- **/
-void
-eog_application_screensaver_disable (EogApplication *application)
-{
-	if (application->priv->scr_saver)
-		totem_scrsaver_disable (application->priv->scr_saver);
-}
-
 static void
 eog_application_load_accelerators (void)
 {
